A checked constant or definition in a kernel environment.
Summary
Types
@type t() :: %Theoria.Env.Constant{ type: Theoria.Term.t(), value: Theoria.Term.t() | nil }
A checked constant or definition in a kernel environment.
@type t() :: %Theoria.Env.Constant{ type: Theoria.Term.t(), value: Theoria.Term.t() | nil }